@@ -12,7 +12,7 @@ use Mail::Mbox::MessageParser::Config;
 
 use vars qw( $VERSION $DEBUG );
 
-$VERSION = sprintf "%d.%02d%02d", q/1.60.4/ =~ /(\d+)/g;
+$VERSION = sprintf "%d.%02d%02d", q/1.60.5/ =~ /(\d+)/g;
 
 *ENTRY_STILL_VALID = \&Mail::Mbox::MessageParser::MetaInfo::ENTRY_STILL_VALID;
 sub ENTRY_STILL_VALID;
@@ -94,7 +94,7 @@ sub _read_prologue
   dprint "Reading mailbox prologue using Perl";
 
   $self->_read_until_match(
-    qr/$Mail::Mbox::MessageParser::Config{'from_pattern'}/,0);
+    qr/$Mail::Mbox::MessageParser::Config{'from_pattern'}/m,0);
 
   my $start_of_email = pos($self->{'READ_BUFFER'});
   $self->{'prologue'} = substr($self->{'READ_BUFFER'}, 0, $start_of_email);
@@ -185,10 +185,14 @@ sub _read_rest_of_email
       do
       {
         $backup_amount *= 2;
+        $backup_amount = $self->{'END_OF_EMAIL'} - $self->{'START_OF_EMAIL'}
+          if $backup_amount >
+            $self->{'END_OF_EMAIL'} - $self->{'START_OF_EMAIL'};
+
         $end_of_string = substr($self->{'READ_BUFFER'},
           $self->{'END_OF_EMAIL'}-$backup_amount, $backup_amount);
       } while (index($end_of_string, "$endline$endline") == -1 &&
-        $backup_amount < $self->{'END_OF_EMAIL'});
+        $backup_amount < $self->{'END_OF_EMAIL'} - $self->{'START_OF_EMAIL'});
 
       next if $end_of_string =~
           /$endline-----(?: Begin Included Message |Original Message)-----$endline[^\r\n]*(?:$endline)*$/i;
@@ -217,7 +221,7 @@ sub _read_rest_of_email
       if length($self->{'READ_BUFFER'}) < $backup_amount;
 
     unless ($self->_read_until_match(
-      qr/$Mail::Mbox::MessageParser::Config{'from_pattern'}/,$backup_amount))
+      qr/$Mail::Mbox::MessageParser::Config{'from_pattern'}/m,$backup_amount))
      {
       $self->{'END_OF_EMAIL'} = length($self->{'READ_BUFFER'});
       return;
@@ -265,7 +269,7 @@ sub _read_email_parts
   # RFC 1521 says the boundary can be no longer than 70 characters. Back up a
   # little more than that.
   my $endline = $self->{'endline'};
-  $self->_read_until_match(qr/^--\Q$boundary\E--$endline/,76)
+  $self->_read_until_match(qr/^--\Q$boundary\E--$endline/m,76)
     or return 0;
 
   return 1;
@@ -298,7 +302,7 @@ sub _read_header
 {
   my $self = shift;
 
-  $self->_read_until_match(qr/$self->{'endline'}$self->{'endline'}/,0)
+  $self->_read_until_match(qr/$self->{'endline'}$self->{'endline'}/m,0)
     or return 0;
 
   $self->{'START_OF_BODY'} =
